@@ -7,6 +7,8 @@ handle higher level of the config file
 
 import os
 import shlex
+import platform
+import distro
 
 
 # local imports
@@ -17,7 +19,7 @@ from dotdrop.profile import Profile
 from dotdrop.action import Action, Transform
 from dotdrop.logger import Logger
 from dotdrop.utils import strip_home, debug_list, debug_dict
-from dotdrop.exceptions import UndefinedException
+from dotdrop.exceptions import UndefinedException, YamlException
 
 
 TILD = '~'
@@ -29,6 +31,12 @@ class CfgAggregator:
     file_prefix = 'f'
     dir_prefix = 'd'
 
+    variable_os = 'os'
+    variable_release = 'release'
+    variable_distro_id = 'distro_id'
+    variable_distro_like = 'distro_like'
+    variable_distro_version = 'distro_version'
+
     def __init__(self, path, profile_key, debug=False, dry=False):
         """
         high level config parser
@@ -41,7 +49,10 @@ class CfgAggregator:
         self.debug = debug
         self.dry = dry
         self.log = Logger(debug=self.debug)
-        self._load()
+        try:
+            self._load()
+        except Exception as exc:
+            raise YamlException(exc) from exc
         self._validate()
 
     ########################################################
@@ -77,13 +88,15 @@ class CfgAggregator:
 
         if not dotfile:
             return False
+        ret = dotfile is not None
 
-        # add to profile
-        key = dotfile.key
-        ret = self.cfgyaml.add_dotfile_to_profile(key, self.profile_key)
-        if ret:
-            msg = 'new dotfile {} to profile {}'
-            self.log.dbg(msg.format(key, self.profile_key))
+        if self.profile_key != self.cfgyaml.key_all:
+            # add to profile
+            key = dotfile.key
+            ret = self.cfgyaml.add_dotfile_to_profile(key, self.profile_key)
+            if ret:
+                msg = f'new dotfile {key} to profile {self.profile_key}'
+                self.log.dbg(msg)
 
         # save the config and reload it
         if ret:
@@ -130,15 +143,18 @@ class CfgAggregator:
         @src: dotfile src (in dotpath)
         @dst: dotfile dst (on filesystem)
         """
-        try:
-            src = self.cfgyaml.resolve_dotfile_src(src)
-        except UndefinedException as exc:
-            err = 'unable to resolve {}: {}'
-            self.log.err(err.format(src, exc))
-            return None
+        if not os.path.isabs(src):
+            # ensures we have an absolute path
+            try:
+                src = self.cfgyaml.resolve_dotfile_src(src)
+            except UndefinedException as exc:
+                err = f'unable to resolve {src}: {exc}'
+                self.log.err(err)
+                return None
         dotfiles = self.get_dotfile_by_dst(dst)
         for dotfile in dotfiles:
-            if dotfile.src == src:
+            dsrc = self.cfgyaml.resolve_dotfile_src(dotfile.src)
+            if dsrc == src:
                 return dotfile
         return None
 
@@ -185,7 +201,13 @@ class CfgAggregator:
         return res
 
     def get_dotfiles(self, profile_key=None):
-        """get all dotfiles for this profile or specified profile key"""
+        """
+        get all dotfiles for the current profile if None
+        or the specified profile_key if defined
+        or all dotfiles if profile_key is ALL
+        """
+        if profile_key == self.cfgyaml.key_all:
+            return self.dotfiles
         dotfiles = []
         profile = self.get_profile(key=profile_key)
         if not profile:
@@ -218,7 +240,7 @@ class CfgAggregator:
         """create a new dotfile"""
         # get a new dotfile with a unique key
         key = self._get_new_dotfile_key(dst)
-        self.log.dbg('new dotfile key: {}'.format(key))
+        self.log.dbg(f'new dotfile key: {key}')
         # add the dotfile
         trans_r_key = trans_w_key = None
         if trans_read:
@@ -280,6 +302,8 @@ class CfgAggregator:
         self.variables = self.cfgyaml.variables
         debug_dict('variables', self.variables, self.debug)
 
+        self._enrich_variables()
+
         # patch dotfiles in profiles
         self._patch_keys_to_objs(self.profiles,
                                  "dotfiles", self.get_dotfile)
@@ -295,7 +319,7 @@ class CfgAggregator:
         self._patch_keys_to_objs([self.settings],
                                  "default_actions", self._get_action_w_args)
 
-        msg = 'default actions: {}'.format(self.settings.default_actions)
+        msg = f'default actions: {self.settings.default_actions}'
         self.log.dbg(msg)
 
         # patch trans_w/trans_r in dotfiles
@@ -308,6 +332,53 @@ class CfgAggregator:
                                  self._get_trans_w_args(self.get_trans_w),
                                  islist=False)
 
+    def _enrich_variables(self):
+        """
+        enrich available variables
+        """
+        if self.variable_os not in self.variables:
+            # enrich with os variable
+            # https://docs.python.org/3/library/platform.html#platform.system
+            var_os = platform.system().lower()
+            self.variables[self.variable_os] = var_os
+            msg = f'enrich variables with {self.variable_os}={var_os}'
+            self.log.dbg(msg)
+        if self.variable_release not in self.variables:
+            # enrich with release variable
+            # https://docs.python.org/3/library/platform.html#platform.release
+            var_release = platform.release().lower()
+            self.variables[self.variable_release] = var_release
+            msg = f'enrich variables with {self.variable_release}'
+            msg += f'={var_release}'
+            self.log.dbg(msg)
+        if self.variable_distro_id not in self.variables:
+            # enrich with distro variable
+            # https://pypi.org/project/distro/
+            # https://distro.readthedocs.io/en/latest/#distro.id
+            var_distro_id = distro.id().lower()
+            self.variables[self.variable_distro_id] = var_distro_id
+            msg = f'enrich variables with {self.variable_distro_id}'
+            msg += f'={var_distro_id}'
+            self.log.dbg(msg)
+        if self.variable_distro_version not in self.variables:
+            # enrich with distro variable
+            # https://pypi.org/project/distro/
+            # https://distro.readthedocs.io/en/latest/#distro.version
+            var_version = distro.version().lower()
+            self.variables[self.variable_distro_version] = var_version
+            msg = f'enrich variables with {self.variable_distro_version}'
+            msg += f'={var_version}'
+            self.log.dbg(msg)
+        if self.variable_distro_like not in self.variables:
+            # enrich with distro variable
+            # https://pypi.org/project/distro/
+            # https://distro.readthedocs.io/en/latest/#distro.like
+            var_like = distro.like().lower()
+            self.variables[self.variable_distro_like] = var_like
+            msg = f'enrich variables with {self.variable_distro_like}'
+            msg += f'={var_like}'
+            self.log.dbg(msg)
+
     def _patch_keys_to_objs(self, containers, keys, get_by_key, islist=True):
         """
         map for each key in the attribute 'keys' in 'containers'
@@ -315,7 +386,7 @@ class CfgAggregator:
         """
         if not containers:
             return
-        self.log.dbg('patching {} ...'.format(keys))
+        self.log.dbg(f'patching {keys} ...')
         for container in containers:
             objects = []
             okeys = getattr(container, keys)
@@ -326,8 +397,8 @@ class CfgAggregator:
             for key in okeys:
                 obj = get_by_key(key)
                 if not obj:
-                    err = '{} does not contain'.format(container)
-                    err += ' a {} entry named {}'.format(keys, key)
+                    err = f'{container} does not contain'
+                    err += f' a {keys} entry named {key}'
                     self.log.err(err)
                     raise Exception(err)
                 objects.append(obj)
@@ -450,8 +521,8 @@ class CfgAggregator:
         if len(fields) > 1:
             # we have args
             key, *args = fields
-            msg = 'action with parm: {} and {}'
-            self.log.dbg(msg.format(key, args))
+            msg = f'action with parm: {key} and {args}'
+            self.log.dbg(msg)
             action = self._get_action(key).copy(args)
         else:
             action = self._get_action(key)
@@ -464,8 +535,8 @@ class CfgAggregator:
             if len(fields) > 1:
                 # we have args
                 key, *args = fields
-                msg = 'trans with parm: {} and {}'
-                self.log.dbg(msg.format(key, args))
+                msg = f'trans with parm: {key} and {args}'
+                self.log.dbg(msg)
                 trans = getter(key).copy(args)
             else:
                 trans = getter(key)
