@@ -8,9 +8,11 @@ diverse exceptions
 
 class YamlException(Exception):
     """exception in CfgYaml"""
-    pass
 
 
 class UndefinedException(Exception):
     """exception in templating"""
-    pass
+
+
+class UnmetDependency(Exception):
+    """unmet dependency"""
